" Vim Keymap file for Serbian characters, classical variant, cp1250 encoding
"
" Maintainer:   Aleksandar Veselinovic <aleksa@cs.cmu.edu>
" URL:		    http://galeb.etf.bg.ac.yu/~alexa/vim/keymap/serbian-cp1250.vim
" Last Changed: 2002 Mar 29

scriptencoding cp1250

let b:keymap_name = "serbian-cp1250"

loadkeymap
Y	Z
{	Š
}	Ð
y	z
[	š
]	ð
:   È
\"	Æ
\|	Ž
;	è
'	æ
\\	ž
"Z	Y
"z	y
<	;
>	:
/	-
_	?
,,	„
''	”

" @	"
" #	'
" $	*
" %	:
" ^	,
" &amp;	.
" *	;

